@@ -7,6 +7,10 @@ from functools import partial
 import yaml
 from django.apps import apps
 from django.contrib.contenttypes.fields import GenericForeignKey
+try:
+    from django.db.models import JSONField
+except ImportError:
+    from django.contrib.postgres.fields.jsonb import JSONField
 from django.contrib.postgres.fields import JSONField
 from django.core.exceptions import ValidationError, FieldDoesNotExist
 from django.core.management.color import no_style
